from pygqlmap.gql_types import *

String = str ##The `String` scalar type represents textual data, represented as UTF-8 character sequences. The String type is most often used by GraphQL to represent free-form human-readable text.

ID = ID ##The `ID` scalar type represents a unique identifier, often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as `"4"`) or integer (such as `4`) input value will be accepted as an ID.

Boolean = bool ##The `Boolean` scalar type represents `true` or `false`.

DateTime = str ##The `DateTime` scalar type represents a DateTime - value as specified by - [iso8601](https://en.wikipedia.org/wiki/ISO_8601).

Float = float ##The `Float` scalar type represents signed double-precision fractional values as specified by [IEEE 754](https://en.wikipedia.org/wiki/IEEE_floating_point).

Int = int ##The `Int` scalar type represents non-fractional signed whole numeric values. Int can represent values between -(2^31) and 2^31 - 1.

Date = str ##The `Date` scalar type represents a Date - value as specified by - [iso8601](https://en.wikipedia.org/wiki/ISO_8601).

BigInt = str ##The `BigInt` scalar type represents non-fractional whole numeric values. - `BigInt` is not constrained to 32-bit like the `Int` type and thus is a less - compatible type.

Decimal = str ##The `Decimal` scalar type represents a python Decimal.

JSONString = str ##Allows use of a JSON String for input / output from the GraphQL schema. -  - Use of this type is *not recommended* as you lose the benefits of having a defined, static - schema (one of the key benefits of GraphQL).

Upload = str ##Create scalar that ignores normal serialization/deserialization, since - that will be handled by the multipart request spec

GenericScalar = str ##The `GenericScalar` scalar type represents a generic - GraphQL scalar value that could be: - String, Boolean, Int, Float, List or Object.



from enum import Enum

class ApprovalStatus(Enum):
   DEFAULT = None
   APPROVAL_NOT_REQUIRED = 'APPROVAL_NOT_REQUIRED'
   EVIDENCE_NEEDED = 'EVIDENCE_NEEDED'
   EVIDENCE_PENDING_APPROVAL = 'EVIDENCE_PENDING_APPROVAL'
   EVIDENCE_APPROVED = 'EVIDENCE_APPROVED'

class MembersMemberConsumptionEvidenceSubmissionStatusChoices(Enum):
   DEFAULT = None
   EVIDENCE_NEEDED = 'EVIDENCE_NEEDED' ##Evidence needed
   EVIDENCE_PENDING_APPROVAL = 'EVIDENCE_PENDING_APPROVAL' ##Evidence pending approval
   EVIDENCE_APPROVED = 'EVIDENCE_APPROVED' ##Evidence approved

class GenerationGenerationFarmGenerationTypeChoices(Enum):
   DEFAULT = None
   WIND = 'WIND' ##Windfarm
   SOL = 'SOL' ##Solarfarm

class GenerationGenerationFarmOperationalStatusChoices(Enum):
   DEFAULT = None
   NA = 'NA' ##N/A
   PRELIMINARY = 'PRELIMINARY' ##Prelimary
   PLANNING = 'PLANNING' ##Planning
   CONTRACTED = 'CONTRACTED' ##Contracted
   UNDER_CONSTRUCTION = 'UNDER_CONSTRUCTION' ##Under construction
   OPERATIONAL = 'OPERATIONAL' ##Operational
   SUSPENDED = 'SUSPENDED' ##Suspended
   DECOMMISSIONED = 'DECOMMISSIONED' ##Decommissioned
   CLOSED = 'CLOSED' ##Closed

class GenerationDataTitle(Enum):
   DEFAULT = None
   TODAY = 'TODAY'
   NEXT_4_DAYS = 'NEXT_4_DAYS'
   NEXT_14_DAYS = 'NEXT_14_DAYS'
   LAST_7_DAYS = 'LAST_7_DAYS'
   LAST_30_DAYS = 'LAST_30_DAYS'

class Period(Enum):
   DEFAULT = None
   Day = 'Day'
   Week = 'Week'
   Month = 'Month'
   Year = 'Year'

class CoopCoopStatusChoices(Enum):
   DEFAULT = None
   RESERVATIONS_OPEN = 'RESERVATIONS_OPEN' ##Reservations open
   RESERVATIONS_CLOSED = 'RESERVATIONS_CLOSED' ##Reservations closed
   OWNERSHIP_OPEN_RESERVED_MEMBERS_ONLY = 'OWNERSHIP_OPEN_RESERVED_MEMBERS_ONLY' ##Ownership open reserved members only
   OWNERSHIP_OPEN = 'OWNERSHIP_OPEN' ##Ownership open
   FULL = 'FULL' ##Full
   BACKFILL = 'BACKFILL' ##Backfill
   CLOSED = 'CLOSED' ##Closed

class PaymentsPaymentCategoryChoices(Enum):
   DEFAULT = None
   JOINING_FEE = 'JOINING_FEE' ##Ripple joining fee
   GIFT_VOUCHER = 'GIFT_VOUCHER' ##Gift Voucher
   ORDER = 'ORDER' ##Order

class InvoiceType(Enum):
   DEFAULT = None
   RESERVATION_RECEIPT = 'RESERVATION_RECEIPT'
   WATTAGE_AMOUNT = 'WATTAGE_AMOUNT'
   ARRANGEMENT_FEE = 'ARRANGEMENT_FEE'
   GIFT_VOUCHER = 'GIFT_VOUCHER'
   INVOICE = 'INVOICE'

class PaymentType(Enum):
   DEFAULT = None
   RESERVATION_FEE = 'RESERVATION_FEE'
   GIFT_VOUCHER = 'GIFT_VOUCHER'
   MONTHLY_INSTALMENT = 'MONTHLY_INSTALMENT'
   INITIAL_INSTALMENT = 'INITIAL_INSTALMENT'
   ONE_TIME_PAYMENT = 'ONE_TIME_PAYMENT'
   PAYMENT = 'PAYMENT'

class PaymentStatus(Enum):
   DEFAULT = None
   PAID = 'PAID'
   FAILED = 'FAILED'
   REFUNDED = 'REFUNDED'
   UPCOMING = 'UPCOMING'
   OVERDUE = 'OVERDUE'

class CrmUserMemoChannelChoices(Enum):
   DEFAULT = None
   DIRECT_EMAIL = 'DIRECT_EMAIL' ##DIRECT_EMAIl
   INFO = 'INFO' ##INFO
   HELP = 'HELP' ##HELP
   CONTACT_US = 'CONTACT_US' ##CONTACT_US
   EMPLOYER = 'EMPLOYER' ##EMPLOYER
   BUSINESS = 'BUSINESS' ##BUSINESS
   OTHER = 'OTHER' ##OTHER

class GetMemberOctopusConsumptionDataTitle(Enum):
   DEFAULT = None
   LAST_7_DAYS = 'LAST_7_DAYS'
   LAST_30_DAYS = 'LAST_30_DAYS'

class SurveyQuestionChoiceTypeChoices(Enum):
   DEFAULT = None
   MULTIPLE_CHOICE = 'MULTIPLE_CHOICE' ##multiple choice
   YES_NO = 'YES_NO' ##yes no
   RADIO = 'RADIO' ##radio
   TEXT = 'TEXT' ##text
   NUMBER = 'NUMBER' ##number

class StripePaymentType(Enum):
   DEFAULT = None
   CARD = 'CARD'

class CardBrandType(Enum):
   DEFAULT = None
   OTHER = 'OTHER'
   VISA = 'VISA'
   MASTERCARD = 'MASTERCARD'



"""Python client for fetching data from Ripple Energy API."""
from requests import post
from pygqlmap.network import GQLResponse
import graphql.queries as gql_query
import graphql.mutations as gql_mutation
import graphql.gql_types as gql_type

class RippleEnergy():
    # init method or constructor
    def __init__(self, email: str = None, password: str = None):
        if email is None:
            return #Replace with exception
        if password is None:
            return #Replace with exception
        if not hasattr(self, "token"):
            self.token = self.token_auth(email = email, password = password)

    def request(self, query = None, url: str = None, headers: dict[str, str] = {}, timeout: int = None):
        """Create a request to the Ripple Energy API, parse and validate response."""
        if query is None:
            return #Replace with exception
        if url is None:
            url = "https://rippleenergy.com/graphql"
        if not hasattr(headers, "Content-Type"):
            headers.update({"Content-Type": "application/json"})
        if hasattr(self, "token") and not hasattr(headers, "Authorization"):
            headers.update({"Authorization": self.token})
        if timeout is None:
            timeout = 10

        response = post(url = url, timeout = timeout, headers = headers, json = {"query": query.export_gql_source})

        gql_response = GQLResponse(response)

        gql_response.print_msg_out()

        gql_response.map_gqldata_to_obj(query.type)

        data = gql_response.result_obj

        return data

    def token_auth(self, email: str = None, password: str = None):
        """Generate authentication token with Ripple Energy API"""
        if email is None:
            return #Replace with exception
        if password is None:
            return #Replace with exception

        mutation = gql_mutation.tokenAuth()
        mutation.name = "TokenAuth"

        mutation_input = gql_type.TokenAuthenticationInput()
        mutation_input.email = email
        mutation_input.password = password

        mutation._args.input = mutation_input

        data = self.request(query = mutation)

        token = f"JWT {data.token}"

        return token

    def auth_login_session(self, email: str = None, password: str = None):
        """Create login session with Ripple Energy API"""
        if email is None:
            return #Replace with exception
        if password is None:
            return #Replace with exception

        mutation = gql_mutation.authLoginSession()
        mutation.name = "AuthLoginSession"

        mutation_input = gql_type.AuthLoginSessionInputType()
        mutation_input.email = email
        mutation_input.password = password

        mutation._args.input = mutation_input

        data = self.request(query = mutation)

        return data

    def auth_logout_session(self):
        """Destroy login session with Ripple Energy API"""
        mutation = gql_mutation.authLogoutSession()
        mutation.name = "AuthLogoutSession"

        data = self.request(query = mutation)

        return data

    def me(self):
        """User information from Ripple Energy API"""
        query = gql_query.me()
        query.name = "Me"

        data = self.request(query = query)

        return data

    def version(self):
        """Version information from Ripple Energy API""" 
        query = gql_query.version()
        query.name = "Version"

        data = self.request(query = query)

        return data

    def branding(self):
        """Branding information from Ripple Energy API""" 
        query = gql_query.branding()
        query.name = "Branding"

        data = self.request(query = query)

        return data

    def products(self):
        """Products information from Ripple Energy API""" 
        query = gql_query.products()
        query.name = "Products"

        data = self.request(query = query)

        return data


from typing import Generic, Union, List
from pygqlmap.components import GQLArgsSet, GQLObject
from pygqlmap.gql_types import *
from pygqlmap.src.arg_builtin import *
from typing import NewType
from .gql_simple_types import *
from .enums import *
from .scalars import *
from .type_refs import *

class DeleteJSONWebTokenCookie(GQLObject):
   deleted: bool

class Verify(GQLObject):
   payload: GenericScalar

class RemoveGiftCard(GQLObject):
   errors: list[str]

class SenderInput(GQLObject):
   firstName: str
   lastName: str
   isAnonymous: bool

class QuoteInput(GQLObject):
   costTotal: float
   percentageOfConsumptionCovered: float
   firstYearBillSavings: float
   projectLifespanBillSavings: float
   annualCo2Savings: float
   projectLifespanInYears: int

class RequestCallBackOutput(GQLObject):
   success: bool

class EmployerContact(GQLObject):
   id: ID
   company: str
   jobTitle: str
   numberOfEmployees: str
   firstname: str
   lastname: str
   phone: str
   email: str
   currentEnergySupplier: str
   annualConsumptionKwh: str
   numberOfSites: str
   message: str
   pathname: str

class UserContact(GQLObject):
   firstname: str
   lastname: str
   email: str

class CreateContactUsMessage(GQLObject):
   id: int

class DeleteNewsOutput(GQLObject):
   success: bool

class SingleNewsFileUpload(GQLObject):
   success: bool

class AddAdditionalWattsInputs(GQLObject):
   memberId: str
   capacity: float
   coopId: str
   costOfWatts: float
   costOfFeesNet: float
   costOfFeesTax: float
   paid: bool
   addInvoiceOnly: bool
   due: str
   invoiceDate: str
   externalInvoiceUrl: str

class ResponseType(GQLObject):
   id: int
   surveyResponseId: int

class CreateMemberBeneficiaryInput(GQLObject):
   nominatedPerson: str
   email: str
   phone: str
   line1: str
   line2: str
   town: str
   postcode: str

class UpdateMemberConsumptionEvidenceSubmissionAdminNoteInput(GQLObject):
   submissionId: str
   adminNote: str

class ConsumptionEvidenceInput(GQLObject):
   file: Upload
   consumption: int

class AuthLoginSessionInputType(GQLObject):
   email: str
   password: str

class DirectDebitInput(GQLObject):
   accountName: str
   accountSortCode: str
   accountNumber: str
   paymentDay: str

class PasswordResetConfirmInput(GQLObject):
   password: str
   passwordConfirm: str
   token: str
   uidb64: str

class UpdateUserInput(GQLObject):
   id: int
   phoneNumber: str

class PayScheduledPaymentInput(GQLObject):
   paymentId: int

class SetKeyValuePair(GQLObject):
   key: str
   value: str
   expiry: str
   command: str

class SingleFileUploadInput(GQLObject):
   file: Upload
   category: str

class UserInput(GQLObject):
   firstName: str
   lastName: str
   email: str
   phoneNumber: str
   password: str
   passwordConfirm: str

class ConsumptionInput(GQLObject):
   electricityAnnual: float
   fromCalculator: bool
   peopleCount: int
   bedroomsCount: int
   hasElectricVehicle: bool
   hasElectricHeating: bool
   hasHeatPump: bool
   hasSolarPanels: bool
   solarPanelsCapacity: float
   acknowledgesToProvideBillEvidence: bool

class PaymentLineInput(GQLObject):
   amount: int
   units: int
   taxAmount: int
   sku: str
   description: str
   params: JSONString

class StripePaymentInput(GQLObject):
   paymentMethodId: str
   paymentIntentId: str

class RegistrationUpdateUserPersonalDetailsInput(GQLObject):
   firstName: str
   lastName: str
   phoneNumber: str

class BillSavingsForecastReference(GQLObject):
   id: ID
   name: str
   href: str

class ReferAFriendPayload(GQLObject):
   hasReferral: bool
   name: str

class RecipientAddress(GQLObject):
   id: int
   line1: str
   line2: str
   town: str
   county: str
   postcode: str
   country: str

class Image(GQLObject):
   id: int
   name: str
   description: str
   thumbnailUrl: str
   bannerUrl: str
   cardUrl: str
   headerUrl: str

class PaymentMethod(GQLObject):
   paymentMethodId: str
   isDefaultPaymentMethod: bool
   paymentType: StripePaymentType
   isCardExpired: bool
   cardBrandType: CardBrandType
   cardExpMonth: str
   cardExpYear: str
   cardLast4: str

class CalculatePaymentLineInput(GQLObject):
   units: int
   amount: int
   sku: str
   params: JSONString

class ValidatedVoucherInfo(GQLObject):
   voucherCode: str
   isValid: bool
   value: int
   message: str

class CoopTimelineProgression(GQLObject):
   timelineProgression: int

class CoopStats(GQLObject):
   name: str
   code: str
   totalCapacity: str
   allocatedCapacity: str
   members: int

class ChoiceType(GQLObject):
   id: ID
   text: str

class SupplierMemberInfoInput(GQLObject):
   apiKey: str
   memberAccountId: str

class FilterInput(GQLObject):
   filterByBusinessMembers: bool
   filterByApprovalStatus: ApprovalStatus

class SearchInput(GQLObject):
   offset: int
   limit: int
   searchTerm: str

class GetMemberMissingInvoiceDataInputs(GQLObject):
   memberId: str
   coopId: str

class Invoice(GQLObject):
   id: ID
   createdAt: DateTime
   description: str
   net: int
   gross: int
   refunded: bool
   category: str
   invoiceUrl: str
   invoiceType: InvoiceType

class DocumentTag(GQLObject):
   id: ID
   name: str

class UserError(GQLObject):
   field: str
   message: str

class InsightsChartCumulativeData(GQLObject):
   cumulativeSavings: float
   cumulativeGenerationKwh: float
   averageWindSpeedMph: float

class DataSetElement(GQLObject):
   netPowerOutputKwh: float
   dateTime: str
   isForecastData: bool
   savingsForPeriod: float

class Currency(GQLObject):
   id: int
   code: str
   precision: int
   symbol: str

class ConsumptionEvidence(GQLObject):
   id: ID
   createdAt: DateTime
   consumption: int
   name: str
   file: str
   fileSizeFormatted: str
   fileUrl: str
   contentType: str

class Supplier(GQLObject):
   id: ID
   name: str
   isRipplePartner: bool
   highlights: str
   logoUrl: str

class Badge(GQLObject):
   id: ID
   name: str
   code: str
   description: str
   imageUrl: str

class GiftCardDesign(GQLObject):
   id: ID
   name: str
   description: str
   postCardCost: int
   image: Image
   currency: Currency

class Recipient(GQLObject):
   id: ID
   email: str
   firstName: str
   lastName: str
   address: RecipientAddress

class GiftCard(GQLObject):
   id: ID
   design: GiftCardDesign
   sender: Sender
   recipient: Recipient
   isSendPostCard: bool
   deliveryDate: Date
   message: str
   amount: int
   currency: Currency
   code: str
   amountLocale: str
   voucherCode: str

class list_UserError(list, UserError): pass

class UpdateGiftCard(GQLObject):
   userErrors: list_UserError[UserError]
   giftCard: GiftCard

class RecipientInput(GQLObject):
   firstName: str
   lastName: str
   email: str
   address: RecipientAddressInput

class GiftCardInput(GQLObject):
   amount: int
   deliveryDate: str
   designId: str
   message: str
   sender: SenderInput
   recipient: RecipientInput
   isSendPostCard: bool

class AddGiftCard(GQLObject):
   userErrors: list_UserError[UserError]
   giftCard: GiftCard

class list_Error(list, Error): pass

class SendQuoteEmail(GQLObject):
   userContact: UserContact
   errors: list_Error[Error]

class CreateEmployerContactOutput(GQLObject):
   employerContact: EmployerContact
   userErrors: list_UserError[UserError]

class CreateUserContact(GQLObject):
   userContact: UserContact
   userErrors: list_UserError[UserError]

class MemberAddress(GQLObject):
   id: ID
   town: str
   country: str
   line1: str
   line2: str
   county: str
   postcode: str
   mpan: str
   mprn: str
   manuallyEntered: bool
   requiresManualSwitch: bool
   hasPrepaidMeter: bool
   selectedFromDropdown: OctopusApiAddress

class list_ConsumptionEvidence(list, ConsumptionEvidence): pass

class MemberConsumptionEvidenceSubmission(GQLObject):
   id: ID
   createdAt: DateTime
   status: MembersMemberConsumptionEvidenceSubmissionStatusChoices
   approvedEvidence: float
   reviewEvidence: float
   memberNote: str
   evidences: list_ConsumptionEvidence[ConsumptionEvidence]
   adminNote: str
   approvedDate: Date
   approvedBy: UserType

class list_MemberConsumptionEvidenceSubmission(list, MemberConsumptionEvidenceSubmission): pass

class MemberConsumptionApproval(GQLObject):
   id: ID
   approvalStatus: ApprovalStatus
   evidenceSubmissions: list_MemberConsumptionEvidenceSubmission[MemberConsumptionEvidenceSubmission]
   latestSubmission: MemberConsumptionEvidenceSubmission
   expectedGenerationKwh: float
   totalApprovedConsumptionKwh: float
   totalUnapprovedConsumptionKwh: float

class list_DataSetElement(list, DataSetElement): pass

class GenerationData(GQLObject):
   title: GenerationDataTitle
   dataSet: list_DataSetElement[DataSetElement]

class list_InsightsChartDataSet(list, InsightsChartDataSet): pass

class InsightsChartDataOutput(GQLObject):
   chartData: list_InsightsChartDataSet[InsightsChartDataSet]
   cumulativeData: InsightsChartCumulativeData
   input: InsightsChartDataInputObject
   userErrors: list_UserError[UserError]

class GenerationDataPoint(GQLObject):
   id: ID
   generationFarm: NewType('GenerationFarm', GQLObject) ## Circular Reference for GenerationFarm
   timestamp: DateTime
   windSpeedAvg: Decimal
   generatorSpeedAvg: Decimal
   bladeAngleAvg: Decimal
   nacellePositionNorth: Decimal

class list_GenerationData(list, GenerationData): pass

class NonNull_InsightsChartDataInput(InsightsChartDataInput): pass

class DEFTF_InsightsChartDataOutput_Field(InsightsChartDataOutput):
   class InsightsChartDataOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_InsightsChartDataInput

   _args: InsightsChartDataOutputArgs



class GenerationFarm(GQLObject):
   id: ID
   currency: Currency
   name: str
   address: Address
   longitude: float
   latitude: float
   isLocationConfirmed: bool
   model: str
   capacity: BigInt
   generationType: GenerationGenerationFarmGenerationTypeChoices
   operationalStatus: GenerationGenerationFarmOperationalStatusChoices
   startDate: Date
   generationData: list_GenerationData[GenerationData]
   lightShowImage: str
   capacityToGenerationFactor: float
#   insightsChartData: DEFTF_InsightsChartDataOutput_Field
   latestGenerationDataPoint: GenerationDataPoint

class list_DocumentTag(list, DocumentTag): pass

class Document(GQLObject):
   id: ID
   updatedAt: DateTime
   name: str
   category: str
   subcategory: str
   description: str
   documentTags: list_DocumentTag[DocumentTag]

class DocumentVersion(GQLObject):
   id: ID
   document: Document
   version: str
   documentUrl: str

class list_DocumentVersion(list, DocumentVersion): pass

class Coop(GQLObject):
   id: ID
   currency: Currency
   name: str
   code: str
   description: str
   generationfarm: GenerationFarm
   status: CoopCoopStatusChoices
   wattageSku: str
   active: bool
   firstYearEstimatedBillSavingsPerWattHour: float
   estimatedBillSavingsPerWattHour: float
   maxCapacityPerMember: BigInt
   minCapacityPerMember: BigInt
   publicCloseDate: DateTime
   percentageFunded: int
   timelineProgression: int
   isAvailableForLocalPurchase: bool
   documents: list_DocumentVersion[DocumentVersion]
   maxGenerationPerMember: int
   minGenerationPerMember: int
   costTotalPerWattHour: float
   localPurchasePostcodes: list[str]

class Voucher(GQLObject):
   id: int
   code: str
   expiry: DateTime
   displayName: str
   payload: VoucherPayload
   error: str
   valid: bool
   allocated: bool

class list_Voucher(list, Voucher): pass

class CoopCapacityQuote(GQLObject):
   id: ID
   currency: Currency
   coop: Coop
   capacity: BigInt
   ownershipMultiplier: float
   capacityCost: int
   arrangementFee: int
   vouchers: list_Voucher[Voucher]
   costTotal: int
   costTotalLocale: str
   electricityConsumptionAnnual: float
   expectedGenerationAnnual: int
   paymentTotal: int
   paymentTotalLocale: str
   instalments: int
   instalmentAmount1: int
   instalmentAmount1Locale: str
   instalmentAmountN: int
   instalmentAmountNLocale: str
   vouchersAmount: int
   vouchersAmountLocale: str
   billSavingsAnnualEstimate: int
   co2SavingsAnnualEstimate: int
   plantedTreesSavingsAnnualEstimate: int
   shareCount: int
   arrangementFeeLocale: str
   arrangementFeeTax: int
   arrangementFeeTaxLocale: str
   arrangementFee1: int
   arrangementFeeLocale1: str
   arrangementFeeTax1: int
   arrangementFeeTaxLocale1: str

class MemberSupplierQuotes(GQLObject):
   id: ID
   supplier: Supplier
   member: NewType('Member', GQLObject) ## Circular Reference for Member
   isAlreadyWithPartnerSupplier: bool
   isAlreadyWithBrandedSupplier: bool
   wantsToSeeTariffs: bool
   switchesToAnotherPartnerSupplier: bool
   electricitySupplierId: int
   postcode: str
   hasEconomy7Meter: bool
   electricityAnnualDayKwh: int
   electricityAnnualNightKwh: int
   gasAnnualKwh: int
   supplierQuotesJson: str
   selectedQuoteCode: str
   switchesGas: bool
   requiresManualSwitch: bool
   isSwitchDelayed: bool
   switchFailed: bool
   switchDisabled: bool
   delayedSwitchDate: Date
   initiated: bool
   acknowledgesTariffsWillBeDifferentInTheFuture: bool
   acknowledgesHeWillLoseSavingsIfHeDoesntSwitchOnTime: bool
   acknowledgesHeNeedsToContactTheSupplierToUpdateAddress: bool
   selectedTariff: JSONString
   currency: Currency
   electricityAnnualStandardKwh: float

class SignUpState(GQLObject):
   id: ID
   createdAt: DateTime
   updatedAt: DateTime
   branding: NewType('Branding', GQLObject) ## Circular Reference for Branding
   address: MemberAddress
   consumption: MemberConsumptionApproval
   quote: CoopCapacityQuote
   supplierQuotes: MemberSupplierQuotes

class list_GQLObject(list, GQLObject): pass

class list_SignUpState(list, SignUpState): pass

class Branding(GQLObject):
   id: ID
   createdAt: DateTime
   updatedAt: DateTime
   cssClassName: str
   displayName: str
   heroImage: ImageGeneral
   howItWorksImage: ImageGeneral
   howDoesItWorkPanelImageFirst: ImageGeneral
   howDoesItWorkPanelImageSecond: ImageGeneral
   howDoesItWorkPanelImageThird: ImageGeneral
   supplier: Supplier
   memberSet: list_GQLObject[GQLObject] ## Circular Reference for Member
   signUpState: list_SignUpState[SignUpState]

class MemberNextOfKin(GQLObject):
   id: ID
   member: NewType('Member', GQLObject) ## Circular Reference for Member
   nominatedPerson: str
   email: str
   phone: str
   line1: str
   line2: str
   town: str
   postcode: str

class MemberConsumption(GQLObject):
   id: ID
   member: NewType('Member', GQLObject) ## Circular Reference for Member
   fromCalculator: bool
   peopleCount: int
   bedroomsCount: int
   hasElectricVehicle: bool
   hasElectricHeating: bool
   hasHeatPump: bool
   hasSolarPanels: bool
   solarPanelsCapacity: float
   acknowledgesToProvideBillEvidence: bool
   electricityAnnualKwh: float

class MemberInvoice(GQLObject):
   id: ID
   quote: CoopCapacityQuote
   category: str
   invoiceUrl: str
   description: str
   gross: int
   net: int

class MemberDocument(GQLObject):
   id: ID
   createdAt: DateTime
   member: NewType('Member', GQLObject) ## Circular Reference for Member
   category: str
   comments: str
   file: str
   documentUrl: str

class MemberSupplier(GQLObject):
   id: ID
   supplier: Supplier
   accountIdentifier: str
   personalApiKey: str
   octopusMpan: str
   octopusMeterSerialNumber: str
   isOctopusApiConnectionVerified: bool
   wantsToSeeOctopusApiConsumptionData: bool

class CoopWaitingList(GQLObject):
   id: ID
   coop: Coop

class MemberCoopWaitingListPlace(GQLObject):
   id: ID
   waitingList: CoopWaitingList
   generationRequestedKwh: int

class list_Badge(list, Badge): pass

class list_MemberNextOfKin(list, MemberNextOfKin): pass

class list_MemberInvoice(list, MemberInvoice): pass

class list_MemberCoopWaitingListPlace(list, MemberCoopWaitingListPlace): pass

class Member(GQLObject):
   id: ID
   registrationCompleted: bool
   communityName: str
   isBusiness: bool
   businessName: str
   businessRegistrationNumber: str
   fullyChargedPreregistered: bool
   badges: list_Badge[Badge]
   branding: Branding
   beneficiaries: list_MemberNextOfKin[MemberNextOfKin]
   address: MemberAddress
   consumption: MemberConsumption
   invoices: list_MemberInvoice[MemberInvoice]
   memberships: list_GQLObject[GQLObject] ## Circular Reference for CoopMembership
   capacityOwnedTotal: BigInt
   ownershipPercentageTotal: float
   memberDocument: MemberDocument
   investmentTotal: int
   billSavingsAcrossAllProjects: int
   expectedGenerationAnnualTotal: BigInt
   hasReservedInActiveCoop: bool
   dateOfReservationInActiveCoop: Date
   dateOfLastSharePurchase: Date
   hasBoughtSharesInActiveCoop: bool
   hasBoughtSharesInGraigFatha: bool
   hasBoughtSharesInKirkHill: bool
   hasBoughtSharesInMultipleCoops: bool
   isSuppliedByOctopusEnergy: bool
   currentMemberSupplier: MemberSupplier
   waitingListPlaces: list_MemberCoopWaitingListPlace[MemberCoopWaitingListPlace]

class CoopMembership(GQLObject):
   id: ID
   createdAt: DateTime
   member: Member
   coop: Coop
   reservedCapacity: BigInt
   ownershipPercentage: float
   investmentTotal: int
   expectedGenerationAnnualTotal: BigInt
   billSavingsFirstYearEstimateTotal: int
   billSavingsForProjectLifespan: int
   firstOwnershipPurchaseDate: Date
   capacity: BigInt
   lightShowImage: str

class UploadLightShowImage(GQLObject):
   coopMembership: CoopMembership
   errors: list_Error[Error]

class Permission(GQLObject):
   """
   userSet - Specific permissions for this user.

   """
   id: ID
   name: str
   codename: str
   groupSet: list_GQLObject[GQLObject] ## Circular Reference for Group
   userSet: list_GQLObject[GQLObject] ## Circular Reference for User

class list_Permission(list, Permission): pass

class Group(GQLObject):
   """
   userSet - The groups this user belongs to. A user will get all permissions granted to each of their groups.

   """
   id: ID
   name: str
   permissions: list_Permission[Permission]
   userSet: list_GQLObject[GQLObject] ## Circular Reference for User

class list_Invoice(list, Invoice): pass

class Payment(GQLObject):
   id: ID
   updatedAt: DateTime
   currency: Currency
   amount: int
   description: str
   category: PaymentsPaymentCategoryChoices
   failed: bool
   paid: bool
   refunded: bool
   dueAt: Date
   amountLocale: str
   memberInvoices: list_MemberInvoice[MemberInvoice]
   invoices: list_Invoice[Invoice]
   paymentType: PaymentType
   status: PaymentStatus
   project: str
   date: Date

class DirectDebit(GQLObject):
   id: ID
   createdAt: DateTime
   updatedAt: DateTime
   user: NewType('User', GQLObject) ## Circular Reference for User
   accountName: str
   accountSortCode: str
   accountNumber: str
   paymentDay: str

class Tracking(GQLObject):
   id: ID
   user: NewType('User', GQLObject) ## Circular Reference for User
   recommendedBy: NewType('User', GQLObject) ## Circular Reference for User

class list_Group(list, Group): pass

class list_Payment(list, Payment): pass

class list_Tracking(list, Tracking): pass

class User(GQLObject):
   """
   groups - The groups this user belongs to. A user will get all permissions granted to each of their groups.

   isStaff - Designates whether the user can log into this admin site.

   isActive - Designates whether this user should be treated as active. Unselect this instead of deleting accounts.

   isGuest - Designates whether this user should be treated as Guest. Guest accounts are created for users who don't want to or can't create an account so it is created for them

   isEmailVerified - Designates whether email has been verified 

   """
   id: ID
   firstName: str
   lastName: str
   groups: list_Group[Group]
   isStaff: bool
   isActive: bool
   isGuest: bool
   dateJoined: DateTime
   isEmailVerified: bool
   createdAt: DateTime
   updatedAt: DateTime
   email: str
   phoneNumber: str
   member: Member
   payments: list_Payment[Payment]
   directDebit: DirectDebit
   referred: list_Tracking[Tracking]
   isSuperuser: bool
   apiKey: str
   consumptionApproval: MemberConsumptionApproval

class UserMemo(GQLObject):
   id: ID
   createdAt: DateTime
   updatedAt: DateTime
   email: str
   note: str
   open: bool
   actionRequired: bool
   channel: CrmUserMemoChannelChoices
   deadline: DateTime
   createdBy: User
   assignedTo: User

class CreateUserMemoOutput(GQLObject):
   memo: UserMemo
   errors: list_Error[Error]

class NewsDocument(GQLObject):
   id: ID
   createdAt: DateTime
   news: NewType('News', GQLObject) ## Circular Reference for News
   category: str
   comments: str
   file: str
   documentUrl: str

class list_NewsDocument(list, NewsDocument): pass

class News(GQLObject):
   id: ID
   title: str
   body: str
   publishDate: DateTime
   hidden: bool
   coop: Coop
   newsDocuments: list_NewsDocument[NewsDocument]

class CreateOrUpdateNewsOutput(GQLObject):
   errors: list_Error[Error]
   news: News

class UpdateQuote(GQLObject):
   quote: CoopCapacityQuote
   errors: list_Error[Error]

class UpdateMemberCommunityName(GQLObject):
   member: Member
   userErrors: list_UserError[UserError]

class UpdateMemberBeneficiaryOutput(GQLObject):
   beneficiary: MemberNextOfKin
   userErrors: list_UserError[UserError]

class CreateMemberBeneficiaryOutput(GQLObject):
   beneficiary: MemberNextOfKin
   userErrors: list_UserError[UserError]

class AddMemberToCoopWaitingListPayload(GQLObject):
   userErrors: list_UserError[UserError]
   waitingListPlace: MemberCoopWaitingListPlace

class ApproveMemberConsumptionEvidenceSubmissionPayload(GQLObject):
   evidenceSubmission: MemberConsumptionEvidenceSubmission
   userErrors: list_UserError[UserError]

class CreateMemberConsumptionEvidenceSubmissionPayload(GQLObject):
   evidenceSubmission: MemberConsumptionEvidenceSubmission
   userErrors: list_UserError[UserError]

class UpdateOctopusApiConsumptionDataVisibilityPayload(GQLObject):
   memberSupplier: MemberSupplier
   userErrors: list_UserError[UserError]

class DisconnectFromOctopusAPIPayload(GQLObject):
   memberSupplier: MemberSupplier
   userErrors: list_UserError[UserError]

class ConnectToOctopusAPIPayload(GQLObject):
   memberSupplier: MemberSupplier
   userErrors: list_UserError[UserError]

class UpdateMemberSupplierAPIKeyPayload(GQLObject):
   memberSupplier: MemberSupplier
   userErrors: list_UserError[UserError]

class UpdateMemberConsumptionNew(GQLObject):
   consumption: MemberConsumption
   userErrors: list_UserError[UserError]

class UpdateMemberConsumptionPayload(GQLObject):
   consumption: MemberConsumption
   errors: list_Error[Error]

class UpdateMemberAddressNew(GQLObject):
   address: MemberAddress
   userErrors: list_UserError[UserError]

class UpdateMemberAddressPayload(GQLObject):
   address: MemberAddress
   errors: list_Error[Error]

class CreateAccountPayload(GQLObject):
   user: UserType
   member: Member
   errors: list_Error[Error]

class AuthenticationCreateAccountOutput(GQLObject):
   user: UserType
   userErrors: list_UserError[UserError]

class RegistrationUpdateOrCreateMemberAddress(GQLObject):
   address: MemberAddress
   userErrors: list_UserError[UserError]

class RegistrationUpdateUserPersonalDetails(GQLObject):
   user: User
   userErrors: list_UserError[UserError]

class UpdateUserCRMOutput(GQLObject):
   user: User
   errors: list_Error[Error]

class PasswordResetConfirmOutput(GQLObject):
   errors: list_Error[Error]
   user: User

class ChangeUserEmail(GQLObject):
   user: User
   errors: list_Error[Error]

class UpdateUserPhoneNumber(GQLObject):
   user: User
   userErrors: list_UserError[UserError]

class UpdateUserOutput(GQLObject):
   user: User
   errors: list_Error[Error]

class StripePaymentResponse(GQLObject):
   requiresAction: bool
   intentClientSecret: str
   errors: list_Error[Error]

class PaymentResponse(GQLObject):
   stripePaymentResponse: StripePaymentResponse
   errors: list_Error[Error]

class Product(GQLObject):
   id: ID
   currency: Currency
   sku: str
   name: str
   description: str
   cost: int
   costUnits: int
   taxPercent: int

class OrderLine(GQLObject):
   id: ID
   product: Product
   units: int
   taxAmount: int

class list_OrderLine(list, OrderLine): pass

class Order(GQLObject):
   id: ID
   totalNetAmount: int
   currency: Currency
   dueAt: DateTime
   status: str
   orderLines: list_OrderLine[OrderLine]

class list_Order(list, Order): pass

class PayOrderResponse(GQLObject):
   paymentResponse: PaymentResponse
   order: Order
   instalmentOrders: list_Order[Order]

class ScheduledPayment(GQLObject):
   id: ID
   amount: int
   description: str
   category: PaymentsPaymentCategoryChoices
   failed: bool
   paid: bool
   refunded: bool
   dueAt: Date
   amountLocale: str
   memberInvoices: list_MemberInvoice[MemberInvoice]

class PayScheduledPaymentResponse(GQLObject):
   paymentResponse: PaymentResponse
   payment: ScheduledPayment

class list_SetKeyValuePair(list, SetKeyValuePair): pass

class ServerEnvOutput(GQLObject):
   store: list_SetKeyValuePair[SetKeyValuePair]
   environment: str
   serverId: str
   serverVersion: str
   errors: list_Error[Error]

class UpdateActiveCoopStatus(GQLObject):
   coop: Coop
   userErrors: list_UserError[UserError]

class AddressInput(GQLObject):
   postcode: str
   line1: str
   line2: str
   town: str
   county: str
   country: str
   mpan: str
   mprn: str
   manuallyEntered: bool
   selectedFromDropdown: OctopusApiAddressInput
   requiresManualSwitch: bool
   hasPrepaidMeter: bool

class CreateAccountInput(GQLObject):
   user: UserInput
   isBusiness: bool
   businessName: str

class PaymentInput(GQLObject):
   uniquePaymentId: str
   description: str
   totalAmount: int
   totalTaxAmount: int
   payAmount: int
   voucherAmount: int
   balanceCreditAmount: int
   balanceDebitAmount: int
   currency: str
   stripePayment: StripePaymentInput
   billingAddress: BillingAddress
   email: str
   voucherCodes: list[str]

#class list_Date(list, Date): pass #To-Do: Clashes

class list_PaymentLineInput(list, PaymentLineInput): pass

class InstalmentInput(GQLObject):
   description: str
   amount: int
   taxAmount: int
#   instalmentDates: list_Date[Date] #To-Do: Clashes
   instalments: int
   lines: list_PaymentLineInput[PaymentLineInput]

class OrderInput(GQLObject):
   currency: str
   lines: list_PaymentLineInput[PaymentLineInput]
   instalments: InstalmentInput

class PayOrderInput(GQLObject):
   payment: PaymentInput
   order: OrderInput

class CreateOwnershipUserInput(GQLObject):
   createAddress: AddressInput
   createSupplierQuotes: UpdateSupplierQuotesInput
   createConsumption: ConsumptionInput
   createQuote: UpdateQuoteInput
   createAccount: CreateAccountInput
   payOrder: PayOrderInput

class CreateOwnershipUser(GQLObject):
   user: User
   userErrors: list_UserError[UserError]

class CreateReservedUserInput(GQLObject):
   createAccount: AuthenticationCreateAccountInput
   updateDetails: RegistrationUpdateUserPersonalDetailsInput
   createAddress: AddressInput
   payOrder: PayOrderInput

class CreateReservedUser(GQLObject):
   user: User
   userErrors: list_UserError[UserError]

class list_BillSavingsForecastDataPoint(list, BillSavingsForecastDataPoint): pass

class list_BillSavingsForecastReference(list, BillSavingsForecastReference): pass

class BillSavingsForecast(GQLObject):
   id: ID
   name: str
   coop: Coop
   isDefault: bool
   description: str
   dataPoints: list_BillSavingsForecastDataPoint[BillSavingsForecastDataPoint]
   references: list_BillSavingsForecastReference[BillSavingsForecastReference]
   paybackPeriodInYears: int
   firstYearPencePerKiloWattHour: float
   totalPencePerKiloWattHour: float

class list_BillSavingsForecast(list, BillSavingsForecast): pass

class BillSavingsForecastsChartData(GQLObject):
   forecasts: list_BillSavingsForecast[BillSavingsForecast]
   defaultForecast: BillSavingsForecast
   maxDataPointPencePerKiloWattHour: float

class Amount(GQLObject):
   currency: Currency
   amount: int
   localeAmount: str

class list_GiftCard(list, GiftCard): pass

class Basket(GQLObject):
   items: list_GiftCard[GiftCard]
   totalAmount: Amount

class list_PaymentMethod(list, PaymentMethod): pass

class PaymentMethodPayload(GQLObject):
   paymentMethods: list_PaymentMethod[PaymentMethod]
   isDefaultCardExpired: bool
   showPaymentMethods: bool
   userErrors: list_UserError[UserError]

class list_CalculatedPaymentLine(list, CalculatedPaymentLine): pass

class CalculateUnitsForCost(GQLObject):
   totalNetAmount: int
   totalTaxAmount: int
   instalments: int
   totalAmount: int
   currency: Currency
   orderLines: list_CalculatedPaymentLine[CalculatedPaymentLine]
   errors: list_Error[Error]

class PaymentPlan(GQLObject):
   totalAmount: int
   totalNetAmount: int
   totalTaxAmount: int
   balanceAmountDebit: int
   balanceAmountCredit: int
   balanceAmountNew: int
   payAmount: int
   orderLines: list_CalculatedPaymentLine[CalculatedPaymentLine]

class InstalmentPaymentPlan(GQLObject):
   totalAmount: int
   totalNetAmount: int
   totalTaxAmount: int
   instalments: int
#   instalmentDates: list_Date[Date] #To-Do: Clashes
   initialPayment: PaymentPlan
   instalmentPayment: PaymentPlan

class list_ValidatedVoucherInfo(list, ValidatedVoucherInfo): pass

class CalculatePayOrder(GQLObject):
   voucherCodes: list_ValidatedVoucherInfo[ValidatedVoucherInfo]
   balanceAmount: int
   voucherAmount: int
   currency: Currency
   singlePaymentPlan: PaymentPlan
   instalmentPaymentPlan: InstalmentPaymentPlan
   errors: list_Error[Error]

class list_News(list, News): pass

class NewsOutput(GQLObject):
   errors: list_Error[Error]
   news: list_News[News]

class QuoteCalculator(GQLObject):
   consumption: float
   minimum: CalculatorMark
   maximum: CalculatorMark
   sliderGenerationStep: float

class list_GetMemberOctopusConsumptionDataSetElement(list, GetMemberOctopusConsumptionDataSetElement): pass

class GetMemberOctopusConsumptionData(GQLObject):
   title: GetMemberOctopusConsumptionDataTitle
   dataSet: list_GetMemberOctopusConsumptionDataSetElement[GetMemberOctopusConsumptionDataSetElement]

class list_GetMemberOctopusConsumptionData(list, GetMemberOctopusConsumptionData): pass

class GetMemberOctopusConsumptionInfo(GQLObject):
   data: list_GetMemberOctopusConsumptionData[GetMemberOctopusConsumptionData]
   userErrors: list_UserError[UserError]

class SupplierMemberInfo(GQLObject):
   member: Member
   errors: list_Error[Error]

class list_UserMemo(list, UserMemo): pass

class UserCRM(GQLObject):
   user: User
   memo: list_UserMemo[UserMemo]

class SearchCountAndFilterInput(GQLObject):
   search: SearchCountInput
   filter: FilterInput

class SearchAndFilterInput(GQLObject):
   search: SearchInput
   filter: FilterInput

class EmailInfo(GQLObject):
   available: bool
   discount: bool
   discountMessage: str
   errors: list_Error[Error]

class list_ChoiceType(list, ChoiceType): pass

class QuestionType(GQLObject):
   id: ID
   question: str
   choiceType: SurveyQuestionChoiceTypeChoices
   choices: list_ChoiceType[ChoiceType]
   order: str
   hidden: bool

class list_QuestionType(list, QuestionType): pass

class SurveyType(GQLObject):
   id: ID
   name: str
   pathName: str
   questions: list_QuestionType[QuestionType]
   forMembersOnly: bool
   secondsUntilDisplay: int
   exact: bool

class list_PublicGenerationDataSet(list, PublicGenerationDataSet): pass

class PublicGenerationData(GQLObject):
   title: GenerationDataTitle
   dataSet: list_PublicGenerationDataSet[PublicGenerationDataSet]

class list_Tag(list, Tag): pass

class Faq(GQLObject):
   id: ID
   question: str
   answer: str
   tags: list_Tag[Tag]

class SavingsData(GQLObject):
   currency: Currency
   month: str
   year: str
   savings: float
   referredSavings: float
   generation: float
   co2Saved: float
   treeEquivalent: int

class CumulativeSavingsData(GQLObject):
   currency: Currency
   savings: float
   generation: float
   co2Saved: float
   lastUpdate: str

class list_CalculatePaymentLineInput(list, CalculatePaymentLineInput): pass

class CalculateOrderPaymentInput(GQLObject):
   balanceAmount: int
   currency: str
   voucherCodes: list[str]
   instalments: int
   orderLines: list_CalculatePaymentLineInput[CalculatePaymentLineInput]

class DeleteCypressTestsData(GQLObject):
   userErrors: list_UserError[UserError]

class TokenAuthenticationOutput(GQLObject):
   token: str
   errors: list_Error[Error]

class SocialAuthLogin(GQLObject):
   userErrors: list_UserError[UserError]

class SocialAuthCreateAccount(GQLObject):
   userErrors: list_UserError[UserError]

class list_GetKeyValuePair(list, GetKeyValuePair): pass

class ClientEnvInput(GQLObject):
   store: list_GetKeyValuePair[GetKeyValuePair]
   siteUrl: str
   path: str
   query: str
   referrerUrl: str
   clientId: str
   clientVersion: str

class PayCapacityQuoteResponse(GQLObject):
   paymentResponse: PaymentResponse
   switchError: str

class PayGiftCardResponse(GQLObject):
   paymentResponse: PaymentResponse

class SetDefaultPaymentMethod(GQLObject):
   success: bool
   userErrors: list_UserError[UserError]

class CreateSetupIntent(GQLObject):
   clientSecret: str
   userErrors: list_UserError[UserError]

class ConfirmAndAddPaymentMethod(GQLObject):
   success: bool
   userErrors: list_UserError[UserError]

class DeleteAlternatePaymentMethod(GQLObject):
   success: bool
   userErrors: list_UserError[UserError]

class InitialiseSignUpStateSession(GQLObject):
   signUpState: SignUpState

class RemoveSignUpStateSession(GQLObject):
   errors: list_Error[Error]

class VerifyEmail(GQLObject):
   errors: list_Error[Error]

class SendEmailVerification(GQLObject):
   user: User

class ChangeUserPasswordResponse(GQLObject):
   errors: list_Error[Error]

class PasswordResetResponse(GQLObject):
   errors: list_Error[Error]

class UpdateUserDirectDebit(GQLObject):
   directDebit: DirectDebit

class UpdateSupplierQuotes(GQLObject):
   supplierQuotes: MemberSupplierQuotes

class RecordSwitchAlreadyInitiated(GQLObject):
   errors: list_Error[Error]

class UpdateMemberIsBusinessField(GQLObject):
   member: Member

class list_ConsumptionEvidenceInput(list, ConsumptionEvidenceInput): pass

class CreateMemberConsumptionEvidenceSubmissionInput(GQLObject):
   files: list_ConsumptionEvidenceInput[ConsumptionEvidenceInput]
   note: str

class CancelMemberConsumptionEvidenceSubmissionPayload(GQLObject):
   userErrors: list_UserError[UserError]

class UpdateMemberConsumptionEvidenceSubmissionAdminNotePayload(GQLObject):
   adminNote: str
   userErrors: list_UserError[UserError]

class RemoveMemberFromCoopWaitingListPayload(GQLObject):
   userErrors: list_UserError[UserError]

class DeleteMemberBeneficiaryOutput(GQLObject):
   userErrors: list_UserError[UserError]

class AddAdditionalWatts(GQLObject):
   errors: list_Error[Error]



from typing import List
from pygqlmap import GQLQuery
from .gql_types import *
from .gql_simple_types import *
from .enums import *
from .scalars import *
from .type_refs import *

class NonNull_GetMemberMissingInvoiceDataInputs(GetMemberMissingInvoiceDataInputs): pass

class NonNull_PaginationInput(PaginationInput): pass

class NonNull_SearchInput(SearchInput): pass

class NonNull_SearchCountInput(SearchCountInput): pass

class list_Coop(list, Coop): pass

class NonNull_SearchAndFilterInput(SearchAndFilterInput): pass

class list_User(list, User): pass

class NonNull_SearchCountAndFilterInput(SearchCountAndFilterInput): pass

class list_Supplier(list, Supplier): pass

class list_OctopusApiAddress(list, OctopusApiAddress): pass

class NonNull_SupplierMemberInfoInput(SupplierMemberInfoInput): pass

class list_SurveyType(list, SurveyType): pass

class list_PublicGenerationData(list, PublicGenerationData): pass

class list_Faq(list, Faq): pass

class list_Currency(list, Currency): pass

class list_Product(list, Product): pass

class NonNull_CalculateOrderPaymentInput(CalculateOrderPaymentInput): pass

class NonNull_CalculateUnitsForCostInput(CalculateUnitsForCostInput): pass

class list_GiftCardDesign(list, GiftCardDesign): pass

class version(GQLQuery):
   type: str

class tribeUrl(GQLQuery):
   type: str

class me(GQLQuery):
   type: User

class branding(GQLQuery):
   type: Branding

class publicPageBranding(GQLQuery):
   class BrandingArgs(GQLArgsSet, GQLObject):
      brand: NonNull_str

   _args: BrandingArgs


   type: Branding

class getMissingInvoiceData(GQLQuery):
   class GetMemberMissingInvoiceDataArgs(GQLArgsSet, GQLObject):
      input: NonNull_GetMemberMissingInvoiceDataInputs

   _args: GetMemberMissingInvoiceDataArgs


   type: GetMemberMissingInvoiceData

class allNews(GQLQuery):
   class NewsArgs(GQLArgsSet, GQLObject):
      input: NonNull_PaginationInput

   _args: NewsArgs


   type: list_News[News]

class searchNews(GQLQuery):
   class NewsArgs(GQLArgsSet, GQLObject):
      input: NonNull_SearchInput

   _args: NewsArgs


   type: list_News[News]

class searchNewsCount(GQLQuery):
   class intArgs(GQLArgsSet, GQLObject):
      input: NonNull_SearchCountInput

   _args: intArgs


   type: int

class getNewsItem(GQLQuery):
   class NewsArgs(GQLArgsSet, GQLObject):
      id: NonNull_str

   _args: NewsArgs


   type: News

class allNewsCount(GQLQuery):
   type: int

class allCoops(GQLQuery):
   type: list_Coop[Coop]

class searchUsers(GQLQuery):
   class UserArgs(GQLArgsSet, GQLObject):
      input: NonNull_SearchAndFilterInput

   _args: UserArgs


   type: list_User[User]

class searchUsersCount(GQLQuery):
   class intArgs(GQLArgsSet, GQLObject):
      input: NonNull_SearchCountAndFilterInput

   _args: intArgs


   type: int

class getUser(GQLQuery):
   class UserCRMArgs(GQLArgsSet, GQLObject):
      id: NonNull_str

   _args: UserCRMArgs


   type: UserCRM

class supplier(GQLQuery):
   class SupplierArgs(GQLArgsSet, GQLObject):
      id: NonNull_str

   _args: SupplierArgs


   type: Supplier

class partnerSuppliers(GQLQuery):
   type: list_Supplier[Supplier]

class addressLookup(GQLQuery):
   class OctopusApiAddressArgs(GQLArgsSet, GQLObject):
      postcode: NonNull_str

   _args: OctopusApiAddressArgs


   type: list_OctopusApiAddress[OctopusApiAddress]

class mpanSupplier(GQLQuery):
   class SupplierArgs(GQLArgsSet, GQLObject):
      mpan: NonNull_str

   _args: SupplierArgs


   type: Supplier

class mprnSupplier(GQLQuery):
   class SupplierArgs(GQLArgsSet, GQLObject):
      mprn: NonNull_str

   _args: SupplierArgs


   type: Supplier

class member(GQLQuery):
   type: Member

class pendingSupplierQuotes(GQLQuery):
   type: MemberSupplierQuotes

class supplierMemberInfo(GQLQuery):
   class SupplierMemberInfoArgs(GQLArgsSet, GQLObject):
      input: NonNull_SupplierMemberInfoInput

   _args: SupplierMemberInfoArgs


   type: SupplierMemberInfo

class address(GQLQuery):
   type: MemberAddress

class consumption(GQLQuery):
   type: MemberConsumption

class checkEmail(GQLQuery):
   class EmailInfoArgs(GQLArgsSet, GQLObject):
      input: NonNull_str

   _args: EmailInfoArgs


   type: EmailInfo

class getMemberOctopusConsumption(GQLQuery):
   type: GetMemberOctopusConsumptionInfo

class memberConsumptionApproval(GQLQuery):
   type: MemberConsumptionApproval

class getSurvey(GQLQuery):
   type: list_SurveyType[SurveyType]

class generationData(GQLQuery):
   type: list_PublicGenerationData[PublicGenerationData]

class coop(GQLQuery):
   type: Coop

class pendingQuote(GQLQuery):
   type: CoopCapacityQuote

class activeCoopStats(GQLQuery):
   type: CoopStats

class quoteCalculator(GQLQuery):
   class QuoteCalculatorArgs(GQLArgsSet, GQLObject):
      consumptionKwh: NonNull_float

   _args: QuoteCalculatorArgs


   type: QuoteCalculator

class coopTimelineProgression(GQLQuery):
   class CoopTimelineProgressionArgs(GQLArgsSet, GQLObject):
      coopCode: NonNull_str

   _args: CoopTimelineProgressionArgs


   type: CoopTimelineProgression

class getNews(GQLQuery):
   type: NewsOutput

class faqs(GQLQuery):
   """
   faqs - if you want to display all faqs, pass an empty string into tag

   """
   class FaqArgs(GQLArgsSet, GQLObject):
      tag: str

   _args: FaqArgs


   type: list_Faq[Faq]

class searchFaqs(GQLQuery):
   class FaqArgs(GQLArgsSet, GQLObject):
      search: NonNull_str

   _args: FaqArgs


   type: list_Faq[Faq]

class monthlySavingsData(GQLQuery):
   class SavingsDataArgs(GQLArgsSet, GQLObject):
      date: NonNull_str

   _args: SavingsDataArgs


   type: SavingsData

class cumulativeSavingsData(GQLQuery):
   type: CumulativeSavingsData

class currencies(GQLQuery):
   class CurrencyArgs(GQLArgsSet, GQLObject):
      codes: NonNull_list[str]

   _args: CurrencyArgs


   type: list_Currency[Currency]

class currency(GQLQuery):
   class CurrencyArgs(GQLArgsSet, GQLObject):
      code: NonNull_str

   _args: CurrencyArgs


   type: Currency

class payments(GQLQuery):
   type: list_Payment[Payment]

class products(GQLQuery):
   type: list_Product[Product]

class orders(GQLQuery):
   type: list_Order[Order]

class calculateOrder(GQLQuery):
   class CalculatePayOrderArgs(GQLArgsSet, GQLObject):
      input: NonNull_CalculateOrderPaymentInput

   _args: CalculatePayOrderArgs


   type: CalculatePayOrder

class calculateUnitsForCost(GQLQuery):
   class CalculateUnitsForCostArgs(GQLArgsSet, GQLObject):
      input: NonNull_CalculateUnitsForCostInput

   _args: CalculateUnitsForCostArgs


   type: CalculateUnitsForCost

class getPaymentMethods(GQLQuery):
   type: PaymentMethodPayload

class checkVouchers(GQLQuery):
   class strArgs(GQLArgsSet, GQLObject):
      codes: NonNull_list[str]

   _args: strArgs


   type: str

class vouchers(GQLQuery):
   class VoucherArgs(GQLArgsSet, GQLObject):
      codes: NonNull_list[str]

   _args: VoucherArgs


   type: list_Voucher[Voucher]

class buyer(GQLQuery):
   type: Buyer

class giftCardDesigns(GQLQuery):
   type: list_GiftCardDesign[GiftCardDesign]

class basket(GQLQuery):
   type: Basket

class ambassador(GQLQuery):
   type: Ambassador

class referAFriend(GQLQuery):
   type: ReferAFriendPayload

class billSavingsForecastsChartData(GQLQuery):
   type: BillSavingsForecastsChartData


class Queries(Enum):
   version = version
   tribeUrl = tribeUrl
   me = me
   branding = branding
   publicPageBranding = publicPageBranding
   getMissingInvoiceData = getMissingInvoiceData
   allNews = allNews
   searchNews = searchNews
   searchNewsCount = searchNewsCount
   getNewsItem = getNewsItem
   allNewsCount = allNewsCount
   allCoops = allCoops
   searchUsers = searchUsers
   searchUsersCount = searchUsersCount
   getUser = getUser
   supplier = supplier
   partnerSuppliers = partnerSuppliers
   addressLookup = addressLookup
   mpanSupplier = mpanSupplier
   mprnSupplier = mprnSupplier
   member = member
   pendingSupplierQuotes = pendingSupplierQuotes
   supplierMemberInfo = supplierMemberInfo
   address = address
   consumption = consumption
   checkEmail = checkEmail
   getMemberOctopusConsumption = getMemberOctopusConsumption
   memberConsumptionApproval = memberConsumptionApproval
   getSurvey = getSurvey
   generationData = generationData
   coop = coop
   pendingQuote = pendingQuote
   activeCoopStats = activeCoopStats
   quoteCalculator = quoteCalculator
   coopTimelineProgression = coopTimelineProgression
   getNews = getNews
   faqs = faqs
   searchFaqs = searchFaqs
   monthlySavingsData = monthlySavingsData
   cumulativeSavingsData = cumulativeSavingsData
   currencies = currencies
   currency = currency
   payments = payments
   products = products
   orders = orders
   calculateOrder = calculateOrder
   calculateUnitsForCost = calculateUnitsForCost
   getPaymentMethods = getPaymentMethods
   checkVouchers = checkVouchers
   vouchers = vouchers
   buyer = buyer
   giftCardDesigns = giftCardDesigns
   basket = basket
   ambassador = ambassador
   referAFriend = referAFriend
   billSavingsForecastsChartData = billSavingsForecastsChartData



from typing import Generic, List
from pygqlmap.components import GQLArgsSet, GQLObject
from pygqlmap.gql_types import *
from pygqlmap.src.arg_builtin import *
from .enums import *
from .scalars import *
from .type_refs import *

class DeleteRefreshTokenCookie(GQLObject):
   deleted: bool

class Refresh(GQLObject):
   payload: GenericScalar
   refreshExpiresIn: int
   token: str

class OpenGiftCard(GQLObject):
   errors: list[str]

class RecipientAddressInput(GQLObject):
   line1: str
   line2: str
   town: str
   postcode: str

class UpdateBuyer(GQLObject):
   id: int
   firstName: str
   lastName: str
   email: str
   isKnown: bool
   isLoggedIn: bool
   errors: list[str]

class RequestCallBackInput(GQLObject):
   firstName: str
   lastName: str
   phoneNumber: str
   companyName: str
   message: str
   pathname: str
   numberOfEmployees: str
   currentEnergySupplier: str
   annualConsumptionKwh: str
   numberOfSites: str

class CreateEmployerContactInput(GQLObject):
   firstname: str
   lastname: str
   email: str
   phone: str
   company: str
   numberOfEmployees: str
   currentEnergySupplier: str
   annualConsumptionKwh: str
   numberOfSites: str
   message: str
   pathname: str
   jobTitle: str

class UserContactInput(GQLObject):
   firstname: str
   lastname: str
   email: str

class CreateContactUsMessageInput(GQLObject):
   name: str
   email: str
   message: str

class CreateUserMemoInputs(GQLObject):
   note: str
   userId: str
   channel: str
   open: bool
   actionRequired: bool

class SingleNewsFileUploadInput(GQLObject):
   file: Upload
   category: str
   newsId: str

class CreateOrUpdateNewsInput(GQLObject):
   id: str
   title: str
   body: str
   hidden: bool
   coopId: str

class ResponseInputType(GQLObject):
   question: str
   surveyResponse: str
   email: str
   multipleChoiceAnswer: list[str]
   radioChoiceAnswer: str
   textFieldAnswer: str
   numberAnswer: int
   yesNoAnswer: str
   surveyId: str

class UpdateMemberBeneficiaryInput(GQLObject):
   beneficiaryId: str
   nominatedPerson: str
   email: str
   phone: str
   line1: str
   line2: str
   town: str
   postcode: str

class AddMemberToCoopWaitingListInput(GQLObject):
   coopId: str
   generationRequestedKwh: int

class ApproveMemberConsumptionEvidenceSubmissionInput(GQLObject):
   submissionId: str
   approvedEvidence: float
   adminNote: str

class AuthLogoutSessionResponseType(GQLObject):
   logoutSuccessful: bool

class AuthLoginSessionResponseType(GQLObject):
   id: int
   loginSuccessful: bool

class UpdateUserCRMInput(GQLObject):
   id: int
   email: str

class ChangeUserPasswordInput(GQLObject):
   currentPassword: str
   newPassword: str
   confirmNewPassword: str

class PayCapacityQuoteInput(GQLObject):
   capacityQuoteId: int
   instalments: int

class GetKeyValuePair(GQLObject):
   key: str
   value: str
   expiry: str

class TokenAuthenticationInput(GQLObject):
   email: str
   password: str

class SingleFileUpload(GQLObject):
   success: bool

class UpdateQuoteInput(GQLObject):
   electricityConsumptionAnnual: int
   voucherCodes: list[str]
   monetaryValue: int
   capacity: int

class UpdateSupplierQuotesInput(GQLObject):
   electricityAnnualStandardKwh: float
   hasEconomy7Meter: bool
   electricityAnnualDayKwh: int
   electricityAnnualNightKwh: int
   switchesGas: bool
   gasAnnualKwh: int
   hasSmartMeter: bool
   postcode: str
   isSwitchDelayed: bool
   switchDisabled: bool
   delayedSwitchDate: Date
   requiresManualSwitch: bool
   supplier: int
   selectedQuoteCode: str
   isAlreadyWithPartnerSupplier: bool
   isAlreadyWithBrandedSupplier: bool
   wantsToSeeTariffs: bool
   switchesToAnotherPartnerSupplier: bool
   electricitySupplierId: int
   acknowledgesTariffsWillBeDifferentInTheFuture: bool
   acknowledgesHeWillLoseSavingsIfHeDoesntSwitchOnTime: bool
   acknowledgesHeNeedsToContactTheSupplierToUpdateAddress: bool

class BillingAddress(GQLObject):
   line1: str
   line2: str
   town: str
   county: str
   postcode: str
   country: str

class OctopusApiAddressInput(GQLObject):
   line1: str
   line2: str
   line3: str
   town: str
   county: str
   postcode: str
   mpans: list[str]
   mprn: str
   gsp: str
   economy7: bool
   prepaidElectricityMeter: bool
   display: str

class AuthenticationCreateAccountInput(GQLObject):
   email: str
   password: str
   path: str

class BillSavingsForecastDataPoint(GQLObject):
   id: ID
   year: int
   pencePerKiloWattHour: float

class Ambassador(GQLObject):
   id: ID
   code: str
   name: str
   showBanner: bool
   headline: str
   subtext: str
   backgroundColor: str
   textColor: str
   logo: str

class Sender(GQLObject):
   id: ID
   isAnonymous: bool
   firstName: str
   lastName: str

class Buyer(GQLObject):
   id: int
   firstName: str
   lastName: str
   email: str
   isKnown: bool
   isLoggedIn: bool

class CalculateUnitsForCostInput(GQLObject):
   currency: str
   instalments: int
   cost: int
   sku: str

class CalculatedPaymentLine(GQLObject):
   amount: int
   units: int
   netAmount: int
   taxAmount: int
   sku: str
   costUnits: int
   unitCost: int
   description: str
   message: str
   params: JSONString
   error: str

class Tag(GQLObject):
   id: ID
   name: str

class CalculatorMark(GQLObject):
   consumptionMet: float
   costTotal: int
   expectedGeneration: float

class PublicGenerationDataSet(GQLObject):
   netPowerOutputKwh: float
   dateTime: str
   windSpeedMph: float
   savingsForPeriod: float
   estimatedCo2Saved: float
   estimatedTreesSaved: float

class GetMemberOctopusConsumptionDataSetElement(GQLObject):
   consumptionKwh: float
   dateTime: str

class Error(GQLObject):
   code: str
   message: str

class SearchCountInput(GQLObject):
   searchTerm: str

class PaginationInput(GQLObject):
   offset: int
   limit: int

class GetMemberMissingInvoiceData(GQLObject):
   capacity: float
   coopId: str
   costOfWatts: float
   costOfFeesNet: float
   costOfFeesTax: float
   invoiceDate: str

class VoucherPayload(GQLObject):
   code: str

class InsightsChartDataInput(GQLObject):
   genFarmId: str
   startDate: str
   endDate: str
   period: Period

class InsightsChartDataInputObject(GQLObject):
   genFarmId: str
   period: Period
   startDate: str
   endDate: str

class InsightsChartDataSet(GQLObject):
   windSpeedMph: float
   generationKwh: float
   savings: float
   fromTime: DateTime
   toTime: DateTime

class Address(GQLObject):
   id: ID
   town: str
   country: str

class UserType(GQLObject):
   id: ID
   firstName: str
   lastName: str
   email: str
   phoneNumber: str

class OctopusApiAddress(GQLObject):
   line1: str
   line2: str
   line3: str
   town: str
   county: str
   postcode: str
   mpans: list[str]
   mprn: str
   gsp: str
   economy7: bool
   prepaidElectricityMeter: bool
   display: str

class ImageGeneral(GQLObject):
   id: ID
   name: str
   description: str
   url: str



from typing import List
from pygqlmap import GQLMutation
from .gql_types import *
from .gql_simple_types import *
from .enums import *
from .scalars import *
from .type_refs import *


class NonNull_CreateReservedUserInput(CreateReservedUserInput): pass

class NonNull_CreateOwnershipUserInput(CreateOwnershipUserInput): pass

class NonNull_SingleFileUploadInput(SingleFileUploadInput): pass

class NonNull_TokenAuthenticationInput(TokenAuthenticationInput): pass

class NonNull_ClientEnvInput(ClientEnvInput): pass

class NonNull_PaymentInput(PaymentInput): pass

class NonNull_PayScheduledPaymentInput(PayScheduledPaymentInput): pass

class NonNull_OrderInput(OrderInput): pass

class NonNull_PayCapacityQuoteInput(PayCapacityQuoteInput): pass

class NonNull_UpdateUserInput(UpdateUserInput): pass

class NonNull_ChangeUserPasswordInput(ChangeUserPasswordInput): pass

class NonNull_PasswordResetConfirmInput(PasswordResetConfirmInput): pass

class NonNull_UpdateUserCRMInput(UpdateUserCRMInput): pass

class NonNull_AddressInput(AddressInput): pass

class NonNull_AuthenticationCreateAccountInput(AuthenticationCreateAccountInput): pass

class NonNull_DirectDebitInput(DirectDebitInput): pass

class NonNull_AuthLoginSessionInputType(AuthLoginSessionInputType): pass

class NonNull_UpdateSupplierQuotesInput(UpdateSupplierQuotesInput): pass

class NonNull_CreateAccountInput(CreateAccountInput): pass

class NonNull_ConsumptionInput(ConsumptionInput): pass

class NonNull_CreateMemberConsumptionEvidenceSubmissionInput(CreateMemberConsumptionEvidenceSubmissionInput): pass

class NonNull_ApproveMemberConsumptionEvidenceSubmissionInput(ApproveMemberConsumptionEvidenceSubmissionInput): pass

class NonNull_UpdateMemberConsumptionEvidenceSubmissionAdminNoteInput(UpdateMemberConsumptionEvidenceSubmissionAdminNoteInput): pass

class NonNull_AddMemberToCoopWaitingListInput(AddMemberToCoopWaitingListInput): pass

class NonNull_CreateMemberBeneficiaryInput(CreateMemberBeneficiaryInput): pass

class NonNull_UpdateMemberBeneficiaryInput(UpdateMemberBeneficiaryInput): pass

class NonNull_UpdateQuoteInput(UpdateQuoteInput): pass

class NonNull_ResponseInputType(ResponseInputType): pass

class NonNull_AddAdditionalWattsInputs(AddAdditionalWattsInputs): pass

class NonNull_CreateOrUpdateNewsInput(CreateOrUpdateNewsInput): pass

class NonNull_SingleNewsFileUploadInput(SingleNewsFileUploadInput): pass

class NonNull_CreateUserMemoInputs(CreateUserMemoInputs): pass

class NonNull_Upload(Upload): pass

class NonNull_CreateContactUsMessageInput(CreateContactUsMessageInput): pass

class NonNull_UserContactInput(UserContactInput): pass

class NonNull_CreateEmployerContactInput(CreateEmployerContactInput): pass

class NonNull_RequestCallBackInput(RequestCallBackInput): pass

class NonNull_QuoteInput(QuoteInput): pass

class NonNull_GiftCardInput(GiftCardInput): pass

class createReservedUser(GQLMutation):
   class CreateReservedUserArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateReservedUserInput

   _args: CreateReservedUserArgs


   type: CreateReservedUser

class createOwnershipUser(GQLMutation):
   class CreateOwnershipUserArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateOwnershipUserInput

   _args: CreateOwnershipUserArgs


   type: CreateOwnershipUser

class deleteCypressTestsData(GQLMutation):
   type: DeleteCypressTestsData

class updateActiveCoopStatus(GQLMutation):
   class UpdateActiveCoopStatusArgs(GQLArgsSet, GQLObject):
      status: NonNull_str

   _args: UpdateActiveCoopStatusArgs


   type: UpdateActiveCoopStatus

class singleFileUpload(GQLMutation):
   class SingleFileUploadArgs(GQLArgsSet, GQLObject):
      input: NonNull_SingleFileUploadInput

   _args: SingleFileUploadArgs


   type: SingleFileUpload

class tokenAuth(GQLMutation):
   class TokenAuthenticationOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_TokenAuthenticationInput

   _args: TokenAuthenticationOutputArgs


   type: TokenAuthenticationOutput

class imitateUser(GQLMutation):
   class TokenAuthenticationOutputArgs(GQLArgsSet, GQLObject):
      id: NonNull_str

   _args: TokenAuthenticationOutputArgs


   type: TokenAuthenticationOutput

class socialAuthLogin(GQLMutation):
   class SocialAuthLoginArgs(GQLArgsSet, GQLObject):
      token: NonNull_str

   _args: SocialAuthLoginArgs


   type: SocialAuthLogin

class socialAuthCreateAccount(GQLMutation):
   class SocialAuthCreateAccountArgs(GQLArgsSet, GQLObject):
      token: NonNull_str

   _args: SocialAuthCreateAccountArgs


   type: SocialAuthCreateAccount

class clientSession(GQLMutation):
   class ServerEnvOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_ClientEnvInput

   _args: ServerEnvOutputArgs


   type: ServerEnvOutput

class payScheduledPayment(GQLMutation):
   class PayScheduledPaymentResponseArgs(GQLArgsSet, GQLObject):
      payment: NonNull_PaymentInput
      scheduledPayment: NonNull_PayScheduledPaymentInput

   _args: PayScheduledPaymentResponseArgs


   type: PayScheduledPaymentResponse

class payOrder(GQLMutation):
   class PayOrderResponseArgs(GQLArgsSet, GQLObject):
      order: NonNull_OrderInput
      payment: NonNull_PaymentInput

   _args: PayOrderResponseArgs


   type: PayOrderResponse

class payCapacityQuote(GQLMutation):
   class PayCapacityQuoteResponseArgs(GQLArgsSet, GQLObject):
      payment: NonNull_PaymentInput
      quote: NonNull_PayCapacityQuoteInput

   _args: PayCapacityQuoteResponseArgs


   type: PayCapacityQuoteResponse

class payGiftCard(GQLMutation):
   class PayGiftCardResponseArgs(GQLArgsSet, GQLObject):
      payment: NonNull_PaymentInput

   _args: PayGiftCardResponseArgs


   type: PayGiftCardResponse

class cancelRefundPayment(GQLMutation):
   class ErrorArgs(GQLArgsSet, GQLObject):
      paymentIds: NonNull_list[NonNull_str]

   _args: ErrorArgs


   type: list_Error[Error]

class setDefaultPaymentMethod(GQLMutation):
   class SetDefaultPaymentMethodArgs(GQLArgsSet, GQLObject):
      paymentMethodId: NonNull_str

   _args: SetDefaultPaymentMethodArgs


   type: SetDefaultPaymentMethod

class createSetupIntent(GQLMutation):
   type: CreateSetupIntent

class confirmAndAddPaymentMethod(GQLMutation):
   class ConfirmAndAddPaymentMethodArgs(GQLArgsSet, GQLObject):
      paymentMethodId: NonNull_str

   _args: ConfirmAndAddPaymentMethodArgs


   type: ConfirmAndAddPaymentMethod

class deleteAlternatePaymentMethod(GQLMutation):
   class DeleteAlternatePaymentMethodArgs(GQLArgsSet, GQLObject):
      paymentMethodId: NonNull_str

   _args: DeleteAlternatePaymentMethodArgs


   type: DeleteAlternatePaymentMethod

class initialiseSignUpStateSession(GQLMutation):
   class InitialiseSignUpStateSessionArgs(GQLArgsSet, GQLObject):
      brandingName: str

   _args: InitialiseSignUpStateSessionArgs


   type: InitialiseSignUpStateSession

class removeSignUpStateSession(GQLMutation):
   type: RemoveSignUpStateSession

class updateUser(GQLMutation):
   class UpdateUserOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_UpdateUserInput

   _args: UpdateUserOutputArgs


   type: UpdateUserOutput

class updateUserPhoneNumber(GQLMutation):
   class UpdateUserPhoneNumberArgs(GQLArgsSet, GQLObject):
      phoneNumber: NonNull_str

   _args: UpdateUserPhoneNumberArgs


   type: UpdateUserPhoneNumber

class verifyEmail(GQLMutation):
   class VerifyEmailArgs(GQLArgsSet, GQLObject):
      token: NonNull_str

   _args: VerifyEmailArgs


   type: VerifyEmail

class sendEmailVerification(GQLMutation):
   class SendEmailVerificationArgs(GQLArgsSet, GQLObject):
      email: NonNull_str
      path: NonNull_str

   _args: SendEmailVerificationArgs


   type: SendEmailVerification

class changeUserPassword(GQLMutation):
   class ChangeUserPasswordResponseArgs(GQLArgsSet, GQLObject):
      input: NonNull_ChangeUserPasswordInput

   _args: ChangeUserPasswordResponseArgs


   type: ChangeUserPasswordResponse

class changeUserEmail(GQLMutation):
   class ChangeUserEmailArgs(GQLArgsSet, GQLObject):
      email: NonNull_str

   _args: ChangeUserEmailArgs


   type: ChangeUserEmail

class passwordResetRequest(GQLMutation):
   class PasswordResetResponseArgs(GQLArgsSet, GQLObject):
      email: NonNull_str

   _args: PasswordResetResponseArgs


   type: PasswordResetResponse

class passwordResetConfirm(GQLMutation):
   class PasswordResetConfirmOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_PasswordResetConfirmInput

   _args: PasswordResetConfirmOutputArgs


   type: PasswordResetConfirmOutput

class updateUserCrm(GQLMutation):
   class UpdateUserCRMOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_UpdateUserCRMInput

   _args: UpdateUserCRMOutputArgs


   type: UpdateUserCRMOutput

class registrationUpdateUserPersonalDetails(GQLMutation):
   class RegistrationUpdateUserPersonalDetailsArgs(GQLArgsSet, GQLObject):
      firstName: NonNull_str
      lastName: NonNull_str
      phoneNumber: NonNull_str

   _args: RegistrationUpdateUserPersonalDetailsArgs


   type: RegistrationUpdateUserPersonalDetails

class registrationUpdateOrCreateMemberAddress(GQLMutation):
   class RegistrationUpdateOrCreateMemberAddressArgs(GQLArgsSet, GQLObject):
      addressInput: NonNull_AddressInput

   _args: RegistrationUpdateOrCreateMemberAddressArgs


   type: RegistrationUpdateOrCreateMemberAddress

class authenticationCreateAccount(GQLMutation):
   class AuthenticationCreateAccountOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_AuthenticationCreateAccountInput

   _args: AuthenticationCreateAccountOutputArgs


   type: AuthenticationCreateAccountOutput

class updateUserDirectDebit(GQLMutation):
   class UpdateUserDirectDebitArgs(GQLArgsSet, GQLObject):
      input: NonNull_DirectDebitInput

   _args: UpdateUserDirectDebitArgs


   type: UpdateUserDirectDebit

class authLoginSession(GQLMutation):
   class AuthLoginSessionResponseTypeArgs(GQLArgsSet, GQLObject):
      input: NonNull_AuthLoginSessionInputType

   _args: AuthLoginSessionResponseTypeArgs


   type: AuthLoginSessionResponseType

class authLogoutSession(GQLMutation):
   type: AuthLogoutSessionResponseType

class updateSupplierQuotes(GQLMutation):
   class UpdateSupplierQuotesArgs(GQLArgsSet, GQLObject):
      input: NonNull_UpdateSupplierQuotesInput

   _args: UpdateSupplierQuotesArgs


   type: UpdateSupplierQuotes

class recordSwitchAlreadyInitiated(GQLMutation):
   type: RecordSwitchAlreadyInitiated

class createAccount(GQLMutation):
   class CreateAccountPayloadArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateAccountInput

   _args: CreateAccountPayloadArgs


   type: CreateAccountPayload

class updateMemberAddress(GQLMutation):
   class UpdateMemberAddressPayloadArgs(GQLArgsSet, GQLObject):
      input: NonNull_AddressInput

   _args: UpdateMemberAddressPayloadArgs


   type: UpdateMemberAddressPayload

class updateMemberAddressNew(GQLMutation):
   class UpdateMemberAddressNewArgs(GQLArgsSet, GQLObject):
      line1: NonNull_str
      line2: NonNull_str
      postcode: NonNull_str
      town: NonNull_str

   _args: UpdateMemberAddressNewArgs


   type: UpdateMemberAddressNew

class updateMemberIsBusinessField(GQLMutation):
   class UpdateMemberIsBusinessFieldArgs(GQLArgsSet, GQLObject):
      isBusiness: NonNull_bool

   _args: UpdateMemberIsBusinessFieldArgs


   type: UpdateMemberIsBusinessField

class updateMemberConsumption(GQLMutation):
   class UpdateMemberConsumptionPayloadArgs(GQLArgsSet, GQLObject):
      input: NonNull_ConsumptionInput

   _args: UpdateMemberConsumptionPayloadArgs


   type: UpdateMemberConsumptionPayload

class updateMemberConsumptionNew(GQLMutation):
   class UpdateMemberConsumptionNewArgs(GQLArgsSet, GQLObject):
      consumptionKwh: NonNull_float

   _args: UpdateMemberConsumptionNewArgs


   type: UpdateMemberConsumptionNew

class updateMemberSupplierApiKey(GQLMutation):
   class UpdateMemberSupplierAPIKeyPayloadArgs(GQLArgsSet, GQLObject):
      apiKey: NonNull_str

   _args: UpdateMemberSupplierAPIKeyPayloadArgs


   type: UpdateMemberSupplierAPIKeyPayload

class connectToOctopusApi(GQLMutation):
   class ConnectToOctopusAPIPayloadArgs(GQLArgsSet, GQLObject):
      apiKey: NonNull_str

   _args: ConnectToOctopusAPIPayloadArgs


   type: ConnectToOctopusAPIPayload

class disconnectFromOctopusApi(GQLMutation):
   type: DisconnectFromOctopusAPIPayload

class updateOctopusApiConsumptionDataVisibility(GQLMutation):
   class UpdateOctopusApiConsumptionDataVisibilityPayloadArgs(GQLArgsSet, GQLObject):
      wantsToSeeOctopusApiConsumptionData: NonNull_bool

   _args: UpdateOctopusApiConsumptionDataVisibilityPayloadArgs


   type: UpdateOctopusApiConsumptionDataVisibilityPayload

class createMemberConsumptionEvidenceSubmission(GQLMutation):
   class CreateMemberConsumptionEvidenceSubmissionPayloadArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateMemberConsumptionEvidenceSubmissionInput

   _args: CreateMemberConsumptionEvidenceSubmissionPayloadArgs


   type: CreateMemberConsumptionEvidenceSubmissionPayload

class approveMemberConsumptionEvidenceSubmission(GQLMutation):
   class ApproveMemberConsumptionEvidenceSubmissionPayloadArgs(GQLArgsSet, GQLObject):
      input: NonNull_ApproveMemberConsumptionEvidenceSubmissionInput

   _args: ApproveMemberConsumptionEvidenceSubmissionPayloadArgs


   type: ApproveMemberConsumptionEvidenceSubmissionPayload

class cancelMemberConsumptionEvidenceSubmission(GQLMutation):
   class CancelMemberConsumptionEvidenceSubmissionPayloadArgs(GQLArgsSet, GQLObject):
      submissionId: NonNull_str

   _args: CancelMemberConsumptionEvidenceSubmissionPayloadArgs


   type: CancelMemberConsumptionEvidenceSubmissionPayload

class updateMemberConsumptionEvidenceSubmissionAdminNote(GQLMutation):
   class UpdateMemberConsumptionEvidenceSubmissionAdminNotePayloadArgs(GQLArgsSet, GQLObject):
      input: NonNull_UpdateMemberConsumptionEvidenceSubmissionAdminNoteInput

   _args: UpdateMemberConsumptionEvidenceSubmissionAdminNotePayloadArgs


   type: UpdateMemberConsumptionEvidenceSubmissionAdminNotePayload

class addMemberToCoopWaitingList(GQLMutation):
   class AddMemberToCoopWaitingListPayloadArgs(GQLArgsSet, GQLObject):
      input: NonNull_AddMemberToCoopWaitingListInput

   _args: AddMemberToCoopWaitingListPayloadArgs


   type: AddMemberToCoopWaitingListPayload

class removeMemberFromCoopWaitingList(GQLMutation):
   class RemoveMemberFromCoopWaitingListPayloadArgs(GQLArgsSet, GQLObject):
      waitingListPlaceId: NonNull_str

   _args: RemoveMemberFromCoopWaitingListPayloadArgs


   type: RemoveMemberFromCoopWaitingListPayload

class createMemberBeneficiary(GQLMutation):
   class CreateMemberBeneficiaryOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateMemberBeneficiaryInput

   _args: CreateMemberBeneficiaryOutputArgs


   type: CreateMemberBeneficiaryOutput

class updateMemberBeneficiary(GQLMutation):
   class UpdateMemberBeneficiaryOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_UpdateMemberBeneficiaryInput

   _args: UpdateMemberBeneficiaryOutputArgs


   type: UpdateMemberBeneficiaryOutput

class deleteMemberBeneficiary(GQLMutation):
   class DeleteMemberBeneficiaryOutputArgs(GQLArgsSet, GQLObject):
      beneficiaryId: NonNull_str

   _args: DeleteMemberBeneficiaryOutputArgs


   type: DeleteMemberBeneficiaryOutput

class updateMemberCommunityName(GQLMutation):
   class UpdateMemberCommunityNameArgs(GQLArgsSet, GQLObject):
      communityName: NonNull_str

   _args: UpdateMemberCommunityNameArgs


   type: UpdateMemberCommunityName

class updateQuote(GQLMutation):
   class UpdateQuoteArgs(GQLArgsSet, GQLObject):
      input: NonNull_UpdateQuoteInput

   _args: UpdateQuoteArgs


   type: UpdateQuote

class createResponse(GQLMutation):
   """
   createResponse - Response referring to survey response

   """
   class ResponseTypeArgs(GQLArgsSet, GQLObject):
      input: NonNull_ResponseInputType

   _args: ResponseTypeArgs


   type: ResponseType

class addAdditionalWatts(GQLMutation):
   class AddAdditionalWattsArgs(GQLArgsSet, GQLObject):
      inputs: NonNull_AddAdditionalWattsInputs

   _args: AddAdditionalWattsArgs


   type: AddAdditionalWatts

class createOrUpdateNews(GQLMutation):
   class CreateOrUpdateNewsOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateOrUpdateNewsInput

   _args: CreateOrUpdateNewsOutputArgs


   type: CreateOrUpdateNewsOutput

class singleNewsFileUpload(GQLMutation):
   class SingleNewsFileUploadArgs(GQLArgsSet, GQLObject):
      input: NonNull_SingleNewsFileUploadInput

   _args: SingleNewsFileUploadArgs


   type: SingleNewsFileUpload

class deleteNews(GQLMutation):
   class DeleteNewsOutputArgs(GQLArgsSet, GQLObject):
      id: NonNull_str

   _args: DeleteNewsOutputArgs


   type: DeleteNewsOutput

class createNote(GQLMutation):
   class CreateUserMemoOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateUserMemoInputs

   _args: CreateUserMemoOutputArgs


   type: CreateUserMemoOutput

class uploadLightShowImage(GQLMutation):
   class UploadLightShowImageArgs(GQLArgsSet, GQLObject):
      coopMembershipId: NonNull_str
      image: NonNull_Upload

   _args: UploadLightShowImageArgs


   type: UploadLightShowImage

class createContactUsMessage(GQLMutation):
   class CreateContactUsMessageArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateContactUsMessageInput

   _args: CreateContactUsMessageArgs


   type: CreateContactUsMessage

class createUserContact(GQLMutation):
   class CreateUserContactArgs(GQLArgsSet, GQLObject):
      input: NonNull_UserContactInput

   _args: CreateUserContactArgs


   type: CreateUserContact

class createEmployerContact(GQLMutation):
   class CreateEmployerContactOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_CreateEmployerContactInput

   _args: CreateEmployerContactOutputArgs


   type: CreateEmployerContactOutput

class requestCallBack(GQLMutation):
   class RequestCallBackOutputArgs(GQLArgsSet, GQLObject):
      input: NonNull_RequestCallBackInput

   _args: RequestCallBackOutputArgs


   type: RequestCallBackOutput

class sendQuoteEmail(GQLMutation):
   class SendQuoteEmailArgs(GQLArgsSet, GQLObject):
      quoteInput: NonNull_QuoteInput
      subscribesToNewsletter: NonNull_bool
      userContactInput: NonNull_UserContactInput

   _args: SendQuoteEmailArgs


   type: SendQuoteEmail

class updateBuyer(GQLMutation):
   class UpdateBuyerArgs(GQLArgsSet, GQLObject):
      email: str

   _args: UpdateBuyerArgs


   type: UpdateBuyer

class addGiftCard(GQLMutation):
   class AddGiftCardArgs(GQLArgsSet, GQLObject):
      input: NonNull_GiftCardInput

   _args: AddGiftCardArgs


   type: AddGiftCard

class updateGiftCard(GQLMutation):
   class UpdateGiftCardArgs(GQLArgsSet, GQLObject):
      giftCardId: NonNull_str
      input: NonNull_GiftCardInput

   _args: UpdateGiftCardArgs


   type: UpdateGiftCard

class removeGiftCard(GQLMutation):
   class RemoveGiftCardArgs(GQLArgsSet, GQLObject):
      id: NonNull_str

   _args: RemoveGiftCardArgs


   type: RemoveGiftCard

class openGiftCard(GQLMutation):
   class OpenGiftCardArgs(GQLArgsSet, GQLObject):
      id: int

   _args: OpenGiftCardArgs


   type: OpenGiftCard

class verifyToken(GQLMutation):
   class VerifyArgs(GQLArgsSet, GQLObject):
      token: str

   _args: VerifyArgs


   type: Verify

class refreshToken(GQLMutation):
   class RefreshArgs(GQLArgsSet, GQLObject):
      token: str

   _args: RefreshArgs


   type: Refresh

class deleteTokenCookie(GQLMutation):
   type: DeleteJSONWebTokenCookie

class deleteRefreshTokenCookie(GQLMutation):
   type: DeleteRefreshTokenCookie


class Mutations(Enum):
   createReservedUser = createReservedUser
   createOwnershipUser = createOwnershipUser
   deleteCypressTestsData = deleteCypressTestsData
   updateActiveCoopStatus = updateActiveCoopStatus
   singleFileUpload = singleFileUpload
   tokenAuth = tokenAuth
   imitateUser = imitateUser
   socialAuthLogin = socialAuthLogin
   socialAuthCreateAccount = socialAuthCreateAccount
   clientSession = clientSession
   payScheduledPayment = payScheduledPayment
   payOrder = payOrder
   payCapacityQuote = payCapacityQuote
   payGiftCard = payGiftCard
   cancelRefundPayment = cancelRefundPayment
   setDefaultPaymentMethod = setDefaultPaymentMethod
   createSetupIntent = createSetupIntent
   confirmAndAddPaymentMethod = confirmAndAddPaymentMethod
   deleteAlternatePaymentMethod = deleteAlternatePaymentMethod
   initialiseSignUpStateSession = initialiseSignUpStateSession
   removeSignUpStateSession = removeSignUpStateSession
   updateUser = updateUser
   updateUserPhoneNumber = updateUserPhoneNumber
   verifyEmail = verifyEmail
   sendEmailVerification = sendEmailVerification
   changeUserPassword = changeUserPassword
   changeUserEmail = changeUserEmail
   passwordResetRequest = passwordResetRequest
   passwordResetConfirm = passwordResetConfirm
   updateUserCrm = updateUserCrm
   registrationUpdateUserPersonalDetails = registrationUpdateUserPersonalDetails
   registrationUpdateOrCreateMemberAddress = registrationUpdateOrCreateMemberAddress
   authenticationCreateAccount = authenticationCreateAccount
   updateUserDirectDebit = updateUserDirectDebit
   authLoginSession = authLoginSession
   authLogoutSession = authLogoutSession
   updateSupplierQuotes = updateSupplierQuotes
   recordSwitchAlreadyInitiated = recordSwitchAlreadyInitiated
   createAccount = createAccount
   updateMemberAddress = updateMemberAddress
   updateMemberAddressNew = updateMemberAddressNew
   updateMemberIsBusinessField = updateMemberIsBusinessField
   updateMemberConsumption = updateMemberConsumption
   updateMemberConsumptionNew = updateMemberConsumptionNew
   updateMemberSupplierApiKey = updateMemberSupplierApiKey
   connectToOctopusApi = connectToOctopusApi
   disconnectFromOctopusApi = disconnectFromOctopusApi
   updateOctopusApiConsumptionDataVisibility = updateOctopusApiConsumptionDataVisibility
   createMemberConsumptionEvidenceSubmission = createMemberConsumptionEvidenceSubmission
   approveMemberConsumptionEvidenceSubmission = approveMemberConsumptionEvidenceSubmission
   cancelMemberConsumptionEvidenceSubmission = cancelMemberConsumptionEvidenceSubmission
   updateMemberConsumptionEvidenceSubmissionAdminNote = updateMemberConsumptionEvidenceSubmissionAdminNote
   addMemberToCoopWaitingList = addMemberToCoopWaitingList
   removeMemberFromCoopWaitingList = removeMemberFromCoopWaitingList
   createMemberBeneficiary = createMemberBeneficiary
   updateMemberBeneficiary = updateMemberBeneficiary
   deleteMemberBeneficiary = deleteMemberBeneficiary
   updateMemberCommunityName = updateMemberCommunityName
   updateQuote = updateQuote
   createResponse = createResponse
   addAdditionalWatts = addAdditionalWatts
   createOrUpdateNews = createOrUpdateNews
   singleNewsFileUpload = singleNewsFileUpload
   deleteNews = deleteNews
   createNote = createNote
   uploadLightShowImage = uploadLightShowImage
   createContactUsMessage = createContactUsMessage
   createUserContact = createUserContact
   createEmployerContact = createEmployerContact
   requestCallBack = requestCallBack
   sendQuoteEmail = sendQuoteEmail
   updateBuyer = updateBuyer
   addGiftCard = addGiftCard
   updateGiftCard = updateGiftCard
   removeGiftCard = removeGiftCard
   openGiftCard = openGiftCard
   verifyToken = verifyToken
   refreshToken = refreshToken
   deleteTokenCookie = deleteTokenCookie
   deleteRefreshTokenCookie = deleteRefreshTokenCookie
